def version(name: str, url: str) -> str: ...
def info(name: str, url: str) -> dict: ...
def main(): ...

class stats:
    def __init__(self, name: str, url: str): ...
    def get_total() -> dict: ...
    def dataset() -> dict: ...